==> Term-Caca-1.0_1.tar.gz: Term-Caca-1.0_1/lib/Term/Kaka.pm <==
package Term::Kaka;
BEGIN {
  $Term::Kaka::AUTHORITY = 'cpan:yanick';
}
BEGIN {
  $Term::Kaka::VERSION = '1.0_1';
}
#ABSTRACT: a subclass of Term::Caca with virtually identical behavior

use strict;
use base 'Term::Caca';
1;



=pod

=head1 NAME

Term::Kaka - a subclass of Term::Caca with virtually identical behavior

=head1 VERSION

version 1.0_1

=head1 SYNOPSIS

Extra thin wrapper for your pleasure

  package Term::Kaka;
  use base 'Term::Caca';
  1;

=head1 WHY?

Somewhere deep in the bowels of gmail.google.com....

Subject: B<libcaca <-- our framebuffer>

B<John Beppu> to Pip

  Pip,

  Based on the name alone, I think this should be the basis of the
  framebuffer for ASCIIker.  Even if the name weren't so apropos, the
  library itself looks really good to me in terms of how it's coded and
  the API that it provides.  I think making a set of perl modules around
  this and making a Term::Caca distribution would be the right thing for
  me to do.

  http://sam.zoy.org/projects/libcaca/

B<Pip Stuart> to me

  My only gripe is ... well the spelling.  I believe it should almost
  always be spelled 'kaka'.  Both spellings have been understood &&
  acceptable according to linguists for quite some time but... my
  highschool friends && I agreed that the K makes it harder && harsher
  ... && when you're discussing kaka... it should be harsh... it should
  sound harsh... it should smell harsh.  The C is like a lame copout &&
  should only be used by the uninformed or for temperament (which I have
  never employed when referring to kaka).  Maybe it's like eskimos with
  tons of names for snow.  I think of all sorts of stuff ... refuse...
  somewhat affectionately yet recognizing the crap nature... in order of
  use: kaka, dung, poop, crap, plop, slop, spit, stuf, shat, stul...
  shit is reserved for extreme occasion.  These are all my 4-letter
  variable names that have been with me for a long time.  This is deeply
  rooted in me &&... I can't imagine ever accepting the C spelling.
  It's weird... I could accept alternate spellings of any of the others
  but I must protest for kaka.  I know it's rather difficult to take
  this complaint seriously since it... well has no technical basis ...
  but kaka is kaka... it's like KAKA!!!  I know that's a lame argument.
  I'm not prepared to defend it more soundly... maybe the module could
  be Term::Kaka that wraps libcaca?  I know that's probably weird but...
  what else can I say?  It should be libkaka.

  -Pip

=head2 but kaka is kaka...  it's like KAKA!!!  -Pip

...as opposed to 'caca', and thus, Term::Kaka was born to make Term::Caca
be, sound, and smell harsh.

=head1 AUTHORS

=over 4

=item *

John Beppu <beppu@cpan.org>

=item *

Yanick Champoux <yanick@cpan.org>

=back

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2011 by John Beppu.

This is free software, licensed under:

  DO WHAT THE FUCK YOU WANT TO PUBLIC LICENSE, Version 2, December 2004

=cut


__END__


# $Id: Kaka.pm,v 1.2 2004/10/22 21:12:01 beppu Exp $

==> Term-Caca-1.1.0.tar.gz: Term-Caca-1.1.0/lib/Term/Kaka.pm <==
package Term::Kaka;
BEGIN {
  $Term::Kaka::AUTHORITY = 'cpan:YANICK';
}
{
  $Term::Kaka::VERSION = '1.1.0';
}
#ABSTRACT: a subclass of Term::Caca with virtually identical behavior

use strict;
use base 'Term::Caca';
1;



=pod

=head1 NAME

Term::Kaka - a subclass of Term::Caca with virtually identical behavior

=head1 VERSION

version 1.1.0

=head1 SYNOPSIS

Extra thin wrapper for your pleasure

  package Term::Kaka;
  use base 'Term::Caca';
  1;

=head1 WHY?

Somewhere deep in the bowels of gmail.google.com....

Subject: B<libcaca <-- our framebuffer>

B<John Beppu> to Pip

  Pip,

  Based on the name alone, I think this should be the basis of the
  framebuffer for ASCIIker.  Even if the name weren't so apropos, the
  library itself looks really good to me in terms of how it's coded and
  the API that it provides.  I think making a set of perl modules around
  this and making a Term::Caca distribution would be the right thing for
  me to do.

  http://sam.zoy.org/projects/libcaca/

B<Pip Stuart> to me

  My only gripe is ... well the spelling.  I believe it should almost
  always be spelled 'kaka'.  Both spellings have been understood &&
  acceptable according to linguists for quite some time but... my
  highschool friends && I agreed that the K makes it harder && harsher
  ... && when you're discussing kaka... it should be harsh... it should
  sound harsh... it should smell harsh.  The C is like a lame copout &&
  should only be used by the uninformed or for temperament (which I have
  never employed when referring to kaka).  Maybe it's like eskimos with
  tons of names for snow.  I think of all sorts of stuff ... refuse...
  somewhat affectionately yet recognizing the crap nature... in order of
  use: kaka, dung, poop, crap, plop, slop, spit, stuf, shat, stul...
  shit is reserved for extreme occasion.  These are all my 4-letter
  variable names that have been with me for a long time.  This is deeply
  rooted in me &&... I can't imagine ever accepting the C spelling.
  It's weird... I could accept alternate spellings of any of the others
  but I must protest for kaka.  I know it's rather difficult to take
  this complaint seriously since it... well has no technical basis ...
  but kaka is kaka... it's like KAKA!!!  I know that's a lame argument.
  I'm not prepared to defend it more soundly... maybe the module could
  be Term::Kaka that wraps libcaca?  I know that's probably weird but...
  what else can I say?  It should be libkaka.

  -Pip

=head2 but kaka is kaka...  it's like KAKA!!!  -Pip

...as opposed to 'caca', and thus, Term::Kaka was born to make Term::Caca
be, sound, and smell harsh.

=head1 AUTHORS

=over 4

=item *

John Beppu <beppu@cpan.org>

=item *

Yanick Champoux <yanick@cpan.org>

=back

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2011 by John Beppu.

This is free software, licensed under:

  DO WHAT THE FUCK YOU WANT TO PUBLIC LICENSE, Version 2, December 2004

=cut


__END__


# $Id: Kaka.pm,v 1.2 2004/10/22 21:12:01 beppu Exp $
